=========
Changelog
=========

Version 0.2.4
===========

- Deprecate --single-thread option

Version 0.2.4
===========

- Use asynchronous version of Click

Version 0.2.3
===========

- Add support for xdist


Version 0.2.2
===========

- Return the same exit code as pytest from coverage command

Version 0.2.1
===========

- Add support for python 3.8

Version 0.2.0
===========

- Upgrade cairo-lang to avoid hacking cairo-runner for overriding VM.

Version 0.1.0-beta
===========

- Provide coverage reports from pytest test suite.
